@@ -598,11 +598,6 @@ static GtkWidget *cache_logs(appdata_t *appdata, cache_context_t *context,
   if(gc_link) {
     GtkWidget *but =
       gtk_button_new_with_label(_("Post a new log entry for this geocache"));
-#if 0
-    gtk_button_set_image(GTK_BUTTON(but), 
-	gtk_image_new_from_stock(GTK_STOCK_ADD, GTK_ICON_SIZE_BUTTON));
-    gtk_button_set_image_position(GTK_BUTTON(but), GTK_POS_LEFT);
-#endif
 #if defined(USE_MAEMO) && (MAEMO_VERSION_MAJOR == 5)
   hildon_gtk_widget_set_theme_size(but, 
 	   (HILDON_SIZE_FINGER_HEIGHT | HILDON_SIZE_AUTO_WIDTH));
@@ -901,7 +896,12 @@ GtkWidget *cache_view(appdata_t *appdata, cache_t *cache) {
     notebook_append_page(notebook, 
 	   cache_hint(appdata, cache), _("Hint"));
 
-  if(cache->log)
+  // always display log page to allow user to post a new log
+  if(cache->log
+#ifdef ENABLE_BROWSER_INTERFACE
+     || (strncmp(cache->id, "GC", 2) == 0)
+#endif
+     ) 
     notebook_append_page(notebook, 
      cache_logs(appdata, cache_context, cache->log, cache->logs_are_html), 
 	   _("Logs"));
