@@ -48,6 +48,10 @@ typedef struct {
   GtkWidget *sat_area;
   GdkPixmap *sat_pixmap;
 
+#ifdef ESPEAK
+  guint espeak_handler;
+#endif
+
 } goto_context_t;
 
 typedef struct cache_context_s {
