@@ -90,6 +90,9 @@ static store_t store[] = {
   { "map_zoom",         STORE_INT,    OFFSET(map.zoom) },
   { "map_source",       STORE_INT,    OFFSET(map.source) },
 #endif
+#ifdef ESPEAK
+  { "espeak/enabled",   STORE_BOOL,   OFFSET(espeak.enabled) },
+#endif
 
   { "geotoad/password", STORE_STRING, OFFSET(gt.password) },
   { "geotoad/filename", STORE_STRING, OFFSET(gt.filename) },
@@ -97,6 +100,7 @@ static store_t store[] = {
   { "geotoad/lat",      STORE_FLOAT,  OFFSET(gt.lat) },
   { "geotoad/lon",      STORE_FLOAT,  OFFSET(gt.lon) },
   { "geotoad/flags",    STORE_INT,    OFFSET(gt.flags) },
+  { "geotoad/no_ownfnd",STORE_BOOL,   OFFSET(gt.no_owned_found) },
 
   { NULL, -1, -1 }
 };
