@@ -67,7 +67,7 @@ typedef struct {
   } log;
 
   GtkWidget *username, *password;
-  GtkWidget *lat, *lon, *dst;
+  GtkWidget *lat, *lon, *dst, *no_of;
   char *filename;
 
   int use_cnt;
@@ -298,14 +298,13 @@ static void arg_dsp(gpointer data, gpointer user_data) {
 
 static void run(gt_context_t *context) {
   GError *error = NULL;
-  char str[8];
 
   /* build list of arguments to call geotoad */
   context->argv = g_ptr_array_new();
   g_ptr_array_add (context->argv, g_strdup_printf(GEOTOAD));
-  g_ascii_dtostr(str, sizeof(str), context->appdata->gt.distance);
   g_ptr_array_add (context->argv, 
-	     g_strdup_printf("--distanceMax=%s", str));
+	     g_strdup_printf("--distanceMax=%u", 
+			     (int)ceil(context->appdata->gt.distance)));
   g_ptr_array_add (context->argv, 
 	     g_strdup_printf("--output=%s", context->appdata->gt.filename));
   g_ptr_array_add (context->argv, 
@@ -315,6 +314,13 @@ static void run(gt_context_t *context) {
   g_ptr_array_add (context->argv,
 	     g_strdup_printf("--user=%s", context->appdata->username));
 
+  if(context->appdata->gt.no_owned_found) {
+    g_ptr_array_add (context->argv,
+	     g_strdup_printf("--userExclude=%s", context->appdata->username));
+    g_ptr_array_add (context->argv,
+	     g_strdup_printf("--ownerExclude=%s", context->appdata->username));
+  }
+
   /* check if we need to add proxy config */
   char *proxy = NULL;
 
@@ -471,10 +477,17 @@ static gboolean gui_setup(gt_context_t *context) {
   gtk_box_pack_start_defaults(GTK_BOX(hbox), popup);
   table_attach(table, hbox, 1, 0);
 
-  float dst = appdata->gt.distance;  // distance is given in kilometers
-  if(appdata->imperial) dst /= 1.609344;
+  hbox = gtk_hbox_new(FALSE, 0);
+  float dst = appdata->gt.distance;  // distance is given in miles
+  if(!appdata->imperial) dst *= 1.609344;
   context->dst = dist_entry_new(dst, appdata->imperial);
-  table_attach(table, context->dst, 1, 1);
+  gtk_box_pack_start_defaults(GTK_BOX(hbox), context->dst);
+
+  context->no_of = check_button_new_with_label(_("No owned/found"));
+  check_button_set_active(context->no_of, appdata->gt.no_owned_found);
+  gtk_box_pack_start_defaults(GTK_BOX(hbox), context->no_of);
+
+  table_attach(table, hbox, 1, 1);
 
   /* ------------------- Username/Password ------------------------- */
   table_attach(table, left_label_new(_("Username:")), 0, 2);
@@ -529,9 +542,11 @@ static gboolean gui_setup(gt_context_t *context) {
     if(context->filename)
       appdata->gt.filename = g_strdup(context->filename);
 
-    /* get distance in kilometers */
-    appdata->gt.distance = dist_entry_get(context->dst, FALSE);
+    /* get distance in miles */
+    appdata->gt.distance = dist_entry_get(context->dst, TRUE);
 
+    /* get "no owned/found" state */
+    appdata->gt.no_owned_found = check_button_get_active(context->no_of);
 
     /* check for valid entries */
     if(isnan(appdata->gt.lat) || isnan(appdata->gt.lon) ||
