@@ -38,6 +38,85 @@
 #define SAT_WIDTH 330
 #define SAT_HEIGHT 60
 
+#ifdef ESPEAK
+#include <espeak/speak_lib.h>
+
+#define ESPEAK_TIMEOUT (15000)   // every 15 seconds
+
+char *espeak_make_string(float dist, gboolean imperial) {
+  char *retval = NULL;
+
+  if(!imperial) {
+    /* distance is in kilometers */
+    if(dist < 2.0/1000.0)
+      retval = g_strdup(_("1 meter"));
+    else if(dist < 1.0)
+      retval = g_strdup_printf(_("%u meters"), (int)(dist*1000));
+    else if(dist < 2.0)
+      retval = g_strdup(_("1 kilometer"));
+    else
+      retval = g_strdup_printf(_("%u kilometers"), (int)dist);
+  } else {
+
+    /* 1 mil = 1760 yd = 5280 ft ... */
+    if(dist < (2.0/5280.0))
+      retval = g_strdup(_("1 foot"));
+    else if(dist < (1.0/1760.0))
+      retval = g_strdup_printf(_("%u feet"), (int)(dist*5280));
+    else if(dist < (2.0/1760.0))
+      retval = g_strdup(_("1 yard"));
+    else if(dist < 1.0)
+      retval = g_strdup_printf(_("%u yard"), (int)(dist*1760));
+    else if(dist < 2.0)
+      retval = g_strdup(_("1 mile"));
+    else
+      retval = g_strdup_printf(_("%u miles"), (int)dist);
+  }
+  return retval;
+}
+
+static gboolean espeak_do(gpointer data) {
+  cache_context_t *context = (cache_context_t*)data;
+
+  pos_t *pos = gps_get_pos(context->appdata);
+  if(pos && !isnan(pos->lat) && !isnan(pos->lon) &&
+     !isnan(context->gotoc.pos.lat) && !isnan(context->gotoc.pos.lon)) {
+
+    /* build distance */
+    float dist = 
+      gpx_pos_get_distance(*pos, context->gotoc.pos,
+			   context->appdata->imperial);
+
+    char *talk = espeak_make_string(dist, context->appdata->imperial);
+
+    unsigned int unique_identifier=0;
+    espeak_Synth(talk, strlen(talk)+1, 0, 0, 0, espeakCHARS_AUTO,
+		 &unique_identifier, NULL);
+    
+    g_free(talk);
+  }
+  
+  return TRUE;  // speak again
+}
+
+static void espeak_enable(cache_context_t *context, gboolean enable) {
+  if(enable) {
+    g_assert(!context->gotoc.espeak_handler);
+
+    context->gotoc.espeak_handler = 
+      gtk_timeout_add(ESPEAK_TIMEOUT, espeak_do, context);  
+
+    espeak_do(context);
+
+  } else {
+    if(context->gotoc.espeak_handler) {
+      gtk_timeout_remove(context->gotoc.espeak_handler);
+      context->gotoc.espeak_handler = 0;
+    }
+  }
+}
+#endif
+
 static float rad2deg(float rad) {
   return fmodf(360.0 + (180.0/M_PI) * rad, 360.0);
 }
@@ -383,6 +462,10 @@ gint goto_destroy_event(GtkWidget *widget, gpointer data ) {
 
   printf("destroying goto view\n");
 
+#ifdef ESPEAK
+  espeak_enable(context, FALSE);
+#endif
+
   /* stop timer */
   if(context->gotoc.handler_id)
     gtk_timeout_remove(context->gotoc.handler_id);
@@ -477,6 +560,20 @@ static void pos_modified(GtkWidget *widget, gpointer data ) {
   goto_update(context);
 }
 
+#ifdef ESPEAK
+static void espeak_clicked(GtkWidget *widget, gpointer data) {
+  cache_context_t *context = (cache_context_t*)data;
+
+  GtkWidget *icon = gtk_button_get_image(GTK_BUTTON(widget));
+  gtk_widget_destroy(icon);
+  context->appdata->espeak.enabled = !context->appdata->espeak.enabled;
+  gtk_button_set_image(GTK_BUTTON(widget), icon_get_widget(ICON_MISC, 
+ 	               context->appdata->espeak.enabled?6:7));
+
+  espeak_enable(context, context->appdata->espeak.enabled);
+}
+#endif
+
 GtkWidget *goto_cache(cache_context_t *context) {
   int i;
 
@@ -564,6 +661,23 @@ GtkWidget *goto_cache(cache_context_t *context) {
 
   gtk_box_pack_start(GTK_BOX(ihbox), context->gotoc.sat_area, 1,0,0);
 
+#ifdef ESPEAK
+  GtkWidget *ivbox = gtk_vbox_new(FALSE, 0);
+  GtkWidget *button = button_new();
+  gtk_button_set_image(GTK_BUTTON(button), icon_get_widget(ICON_MISC, 
+ 	               context->appdata->espeak.enabled?6:7));
+  gtk_signal_connect (GTK_OBJECT(button), "clicked", 
+		      GTK_SIGNAL_FUNC(espeak_clicked), context);
+  if(context->appdata->espeak.sample_rate < 0)
+    gtk_widget_set_sensitive(button, FALSE);
+  else
+    if(context->appdata->espeak.enabled)
+      espeak_enable(context, TRUE);
+
+  gtk_box_pack_start(GTK_BOX(ivbox), button, 1,0,0);
+  gtk_box_pack_start(GTK_BOX(ihbox), ivbox, 1,0,0);
+#endif
+
   gtk_table_attach_defaults(GTK_TABLE(table), ihbox, 0,3,5,6);
 
   /* ------------------------------------------------------- */
