@@ -44,10 +44,10 @@ gps_sat_t *gps_get_sats(appdata_t *appdata) {
   gps_sat_t *retval = NULL;
 
   g_mutex_lock(appdata->gps_state->mutex);
-  if(appdata->gps_state->gpsdata.set & SATELLITE_SET) {
+  if(appdata->gps_state->set & SATELLITE_SET) {
     int i;
     retval = malloc(sizeof(gps_sat_t));
-    retval->num = appdata->gps_state->gpsdata.satellites;
+    retval->num = appdata->gps_state->satellites;
 
     retval->PRN  = malloc(sizeof(int)*retval->num);
     retval->used = malloc(sizeof(int)*retval->num);
@@ -55,9 +55,9 @@ gps_sat_t *gps_get_sats(appdata_t *appdata) {
 
     if(retval->num) {
       for(i=0;i<retval->num;i++) {
-	retval->PRN[i]  = appdata->gps_state->gpsdata.PRN[i];
-	retval->ss[i]   = appdata->gps_state->gpsdata.ss[i];
-	retval->used[i] = appdata->gps_state->gpsdata.used[i];
+	retval->PRN[i]  = appdata->gps_state->PRN[i];
+	retval->ss[i]   = appdata->gps_state->ss[i];
+	retval->used[i] = appdata->gps_state->used[i];
       }
     }
   }
@@ -73,10 +73,10 @@ pos_t *gps_get_pos(appdata_t *appdata) {
   retval.lat = NAN;
 
   g_mutex_lock(appdata->gps_state->mutex);
-  if(appdata->gps_state->gpsdata.set & STATUS_SET)
-    if(appdata->gps_state->gpsdata.status != STATUS_NO_FIX)
-      if(appdata->gps_state->gpsdata.set & LATLON_SET) 
-	retval = appdata->gps_state->gpsdata.fix.pos;
+  if(appdata->gps_state->set & STATUS_SET)
+    if(appdata->gps_state->status != STATUS_NO_FIX)
+      if(appdata->gps_state->set & LATLON_SET) 
+	retval = appdata->gps_state->fix.pos;
 
   g_mutex_unlock(appdata->gps_state->mutex);
 
@@ -90,10 +90,10 @@ float gps_get_heading(appdata_t *appdata) {
   float retval = NAN;
 
   g_mutex_lock(appdata->gps_state->mutex);
-  if(appdata->gps_state->gpsdata.set & STATUS_SET)
-    if(appdata->gps_state->gpsdata.status != STATUS_NO_FIX) 
-      if(appdata->gps_state->gpsdata.set & TRACK_SET) 
-	retval = appdata->gps_state->gpsdata.fix.track;
+  if(appdata->gps_state->set & STATUS_SET)
+    if(appdata->gps_state->status != STATUS_NO_FIX) 
+      if(appdata->gps_state->set & TRACK_SET) 
+	retval = appdata->gps_state->fix.track;
 
   g_mutex_unlock(appdata->gps_state->mutex);
   return retval;
@@ -103,9 +103,9 @@ float gps_get_eph(appdata_t *appdata) {
   float retval = NAN;
 
   g_mutex_lock(appdata->gps_state->mutex);
-  if(appdata->gps_state->gpsdata.set & STATUS_SET)
-    if(appdata->gps_state->gpsdata.status != STATUS_NO_FIX) 
-      retval = appdata->gps_state->gpsdata.fix.eph;
+  if(appdata->gps_state->set & STATUS_SET)
+    if(appdata->gps_state->status != STATUS_NO_FIX) 
+      retval = appdata->gps_state->fix.eph;
 
   g_mutex_unlock(appdata->gps_state->mutex);
   return retval;
@@ -186,7 +186,7 @@ void gps_clear_fix(struct gps_fix_t *fixp) {
 }
 
 /* unpack a daemon response into a status structure */
-static void gps_unpack(char *buf, struct gps_data_t *gpsdata) {
+static void gps_unpack(char *buf, struct gps_state *state) {
   char *ns, *sp, *tp;
 
   for(ns = buf; ns; ns = strstr(ns+1, "GPSD")) {
@@ -203,13 +203,13 @@ static void gps_unpack(char *buf, struct gps_data_t *gpsdata) {
 	  /* C - cycle isn't supported by gpxview */
 	  /* D - utc time isn't supported by gpxview */
 	case 'E':
-	  gpsdata->fix.eph = NAN;
+	  state->fix.eph = NAN;
 	  /* epe should always be present if eph or epv is */
 	  if (sp[2] != '?') {
 	    char epe[20], eph[20], epv[20];
 	    (void)sscanf(sp, "E=%s %s %s", epe, eph, epv);
 #define DEFAULT(val) (val[0] == '?') ? NAN : g_ascii_strtod(val, NULL)
-	    gpsdata->fix.eph = DEFAULT(eph);
+	    state->fix.eph = DEFAULT(eph);
 #undef DEFAULT
 	  }
 	  break;
@@ -218,20 +218,20 @@ static void gps_unpack(char *buf, struct gps_data_t *gpsdata) {
 	  /* K - known devices list isn't supported by gpxview */
 	case 'M':
 	  if (sp[2] == '?') {
-	    gpsdata->fix.mode = MODE_NOT_SEEN;
+	    state->fix.mode = MODE_NOT_SEEN;
 	  } else {
-	    gpsdata->fix.mode = atoi(sp+2);
-	    gpsdata->set |= MODE_SET;
+	    state->fix.mode = atoi(sp+2);
+	    state->set |= MODE_SET;
 	  }
 	  break;
 	  /* N - driver mode reporting isn't supported by gpxview */
 	case 'O':
 	  if (sp[2] == '?') {
-	    gpsdata->set = 
-	      (gpsdata->set & SATELLITE_SET) | // fix for below
+	    state->set = 
+	      (state->set & SATELLITE_SET) | // fix for below
 	      MODE_SET | STATUS_SET;  // this clears sat info??
-	    gpsdata->status = STATUS_NO_FIX;
-	    gps_clear_fix(&gpsdata->fix);
+	    state->status = STATUS_NO_FIX;
+	    gps_clear_fix(&state->fix);
 	  } else {
 	    struct gps_fix_t nf;
 	    char tag[MAXTAGLEN+1], alt[20];
@@ -255,43 +255,43 @@ static void gps_unpack(char *buf, struct gps_data_t *gpsdata) {
 	      else
 		nf.mode = (alt[0] == '?') ? MODE_2D : MODE_3D;
 	      if (isnan(nf.eph)==0)
-		gpsdata->set |= HERR_SET;
+		state->set |= HERR_SET;
 	      if (isnan(nf.track)==0)
-		gpsdata->set |= TRACK_SET;
-	      gpsdata->fix = nf;
-	      gpsdata->set |= LATLON_SET|MODE_SET;
-	      gpsdata->status = STATUS_FIX;
-	      gpsdata->set |= STATUS_SET;
+		state->set |= TRACK_SET;
+	      state->fix = nf;
+	      state->set |= LATLON_SET|MODE_SET;
+	      state->status = STATUS_FIX;
+	      state->set |= STATUS_SET;
 	    }
 	  }
 	  break;
 	case 'P':
 	  if (sp[2] == '?') {
-	    gpsdata->fix.pos.lat = NAN;
-	    gpsdata->fix.pos.lon = NAN;
+	    state->fix.pos.lat = NAN;
+	    state->fix.pos.lon = NAN;
 	  } else {
 	    char lat[20], lon[20];
 	    (void)sscanf(sp, "P=%19s %19s", lat, lon);
-	    gpsdata->fix.pos.lat = g_ascii_strtod(lat, NULL);
-	    gpsdata->fix.pos.lon = g_ascii_strtod(lon, NULL);
-	    gpsdata->set |= LATLON_SET;
+	    state->fix.pos.lat = g_ascii_strtod(lat, NULL);
+	    state->fix.pos.lon = g_ascii_strtod(lon, NULL);
+	    state->set |= LATLON_SET;
 	  }
 	  break;
 	  /* Q is not supported */
 	case 'S':
 	  if (sp[2] == '?') {
-	    gpsdata->status = -1;
+	    state->status = -1;
 	  } else {
-	    gpsdata->status = atoi(sp+2);
-	    gpsdata->set |= STATUS_SET;
+	    state->status = atoi(sp+2);
+	    state->set |= STATUS_SET;
 	  }
 	  break;
 	case 'T':
 	  if (sp[2] == '?') {
-	    gpsdata->fix.track = NAN;
+	    state->fix.track = NAN;
 	  } else {
-	    (void)sscanf(sp, "T=%f", &gpsdata->fix.track);
-	    gpsdata->set |= TRACK_SET;
+	    (void)sscanf(sp, "T=%f", &state->fix.track);
+	    state->set |= TRACK_SET;
 	  }
 	  break;
 	  /* U - climb is not supported */
@@ -299,7 +299,7 @@ static void gps_unpack(char *buf, struct gps_data_t *gpsdata) {
 	  /* X - online is not supported */
 	case 'Y':
 	  if (sp[2] == '?') {
-	    gpsdata->satellites = 0;
+	    state->satellites = 0;
 	  } else {
 	    int j, i1, i2, i3, i4, i5;
 	    int PRN[MAXCHANNELS];
@@ -308,12 +308,12 @@ static void gps_unpack(char *buf, struct gps_data_t *gpsdata) {
 	    char tag[MAXTAGLEN+1], timestamp[21];
 	    
 	    (void)sscanf(sp, "Y=%8s %20s %d ", 
-			 tag, timestamp, &gpsdata->satellites);
-	    for (j = 0; j < gpsdata->satellites; j++) {
+			 tag, timestamp, &state->satellites);
+	    for (j = 0; j < state->satellites; j++) {
 	      PRN[j]=elevation[j]=azimuth[j]=ss[j]=used[j]=0;
 	    }
-	    //	    printf("gps: sats = %d\n", gpsdata->satellites);
-	    for (j = 0, gpsdata->satellites_used = 0; j < gpsdata->satellites; j++) {
+	    //	    printf("gps: sats = %d\n", state->satellites);
+	    for (j = 0, state->satellites_used = 0; j < state->satellites; j++) {
 	      if ((sp != NULL) && ((sp = strchr(sp, ':')) != NULL)) {
 		sp++;
 		(void)sscanf(sp, "%d %d %d %d %d", &i1, &i2, &i3, &i4, &i5);
@@ -321,17 +321,17 @@ static void gps_unpack(char *buf, struct gps_data_t *gpsdata) {
 		elevation[j] = i2; azimuth[j] = i3;
 		ss[j] = i4; used[j] = i5;
 		if (i5 == 1)
-		  gpsdata->satellites_used++;
+		  state->satellites_used++;
 	      }
 	    }
-	    memcpy(gpsdata->PRN, PRN, sizeof(PRN));
-	    memcpy(gpsdata->elevation, elevation, sizeof(elevation));
-	    memcpy(gpsdata->azimuth, azimuth,sizeof(azimuth));
-			memcpy(gpsdata->ss, ss, sizeof(ss));
-			memcpy(gpsdata->used, used, sizeof(used));
+	    memcpy(state->PRN, PRN, sizeof(PRN));
+	    memcpy(state->elevation, elevation, sizeof(elevation));
+	    memcpy(state->azimuth, azimuth,sizeof(azimuth));
+			memcpy(state->ss, ss, sizeof(ss));
+			memcpy(state->used, used, sizeof(used));
 			/*@ +compdef @*/
 	  }
-	  gpsdata->set |= SATELLITE_SET;
+	  state->set |= SATELLITE_SET;
 	  break;
 	  /* Z and $ - profiling isn't supported by gpxview */
 	}
@@ -367,7 +367,7 @@ gpointer gps_thread(gpointer data) {
   const char *msg_pos = "o\r\n";   /* pos request */
   const char *msg_sat = "y\r\n";   /* sat request */
 
-  appdata->gps_state->gpsdata.set = 0;
+  appdata->gps_state->set = 0;
 
   gboolean connected = FALSE;
 
@@ -404,11 +404,11 @@ gpointer gps_thread(gpointer data) {
 	      
 	      g_mutex_lock(appdata->gps_state->mutex);
 	      
-	      if(!cnt) appdata->gps_state->gpsdata.set &= ~SATELLITE_SET;
-	      else     appdata->gps_state->gpsdata.set &= 
+	      if(!cnt) appdata->gps_state->set &= ~SATELLITE_SET;
+	      else     appdata->gps_state->set &= 
 			 ~(LATLON_SET|MODE_SET|STATUS_SET);
 	    
-	      gps_unpack(str, &appdata->gps_state->gpsdata);
+	      gps_unpack(str, appdata->gps_state);
 	      g_mutex_unlock(appdata->gps_state->mutex);
 	      g_idle_add(gps_idle_cb, appdata); 
 	    }
