@@ -46,35 +46,6 @@ struct gps_fix_t {
 
 typedef unsigned int gps_mask_t;
 
-struct gps_data_t {
-    gps_mask_t set;	/* has field been set since this was last cleared? */
-#define LATLON_SET	0x00000008u
-#define SPEED_SET	0x00000020u
-#define TRACK_SET	0x00000040u
-#define STATUS_SET	0x00000100u
-#define MODE_SET	0x00000200u
-#define HERR_SET	0x00008000u
-#define SATELLITE_SET	0x00040000u
-    struct gps_fix_t	fix;		/* accumulated PVT data */
-
-    /* GPS status -- always valid */
-    int    status;		/* Do we have a fix? */
-#define STATUS_NO_FIX	0	/* no */
-#define STATUS_FIX	1	/* yes, without DGPS */
-#define STATUS_DGPS_FIX	2	/* yes, with DGPS */
-
-    /* precision of fix -- valid if satellites_used > 0 */
-    int satellites_used;	/* Number of satellites used in solution */
-    int used[MAXCHANNELS];	/* PRNs of satellites used in solution */
-
-    /* satellite status -- valid when satellites > 0 */
-    int satellites;		/* # of satellites in view */
-    int PRN[MAXCHANNELS];	/* PRNs of satellite */
-    int elevation[MAXCHANNELS];	/* elevation of satellite */
-    int azimuth[MAXCHANNELS];	/* azimuth */
-    int ss[MAXCHANNELS];	/* signal-to-noise ratio (dB) */
-};
-
 #ifdef USE_MAEMO
 #ifdef ENABLE_GPSBT
 #include <gpsbt.h>
@@ -95,7 +66,7 @@ typedef struct {
   int *used;
 } gps_sat_t;
 
-typedef void (*gps_cb)(struct gps_state *, gpointer data);
+typedef void (*gps_cb)(struct gps_state *state, void *data);
 #define	GPS_CB(f) ((gps_cb)(f))
 
 typedef struct {
@@ -103,6 +74,13 @@ typedef struct {
   gpointer data;
 } gps_cb_t;
 
+#define LATLON_SET	0x00000008u
+#define TRACK_SET	0x00000040u
+#define STATUS_SET	0x00000100u
+#define MODE_SET	0x00000200u
+#define HERR_SET	0x00008000u
+#define SATELLITE_SET	0x00040000u
+
 typedef struct gps_state {
 #ifndef ENABLE_LIBLOCATION
 #ifdef ENABLE_GPSBT
@@ -114,7 +92,26 @@ typedef struct gps_state {
   GnomeVFSInetConnection *iconn;
   GnomeVFSSocket *socket;
 
-  struct gps_data_t gpsdata;
+  gps_mask_t set;	/* has field been set since this was last cleared? */
+  struct gps_fix_t	fix;		/* accumulated PVT data */
+
+  /* GPS status -- always valid */
+  int    status;		/* Do we have a fix? */
+#define STATUS_NO_FIX	0	/* no */
+#define STATUS_FIX	1	/* yes, without DGPS */
+#define STATUS_DGPS_FIX	2	/* yes, with DGPS */
+  
+  /* precision of fix -- valid if satellites_used > 0 */
+  int satellites_used;	/* Number of satellites used in solution */
+  int used[MAXCHANNELS];	/* PRNs of satellites used in solution */
+  
+  /* satellite status -- valid when satellites > 0 */
+  int satellites;		/* # of satellites in view */
+  int PRN[MAXCHANNELS];	/* PRNs of satellite */
+  int elevation[MAXCHANNELS];	/* elevation of satellite */
+  int azimuth[MAXCHANNELS];	/* azimuth */
+  int ss[MAXCHANNELS];	/* signal-to-noise ratio (dB) */
+  
 #else
   LocationGPSDevice *device;
   LocationGPSDControl *control;
