@@ -228,8 +228,17 @@ typedef struct {
     char *password, *filename;
     float distance, lat, lon;
     int flags;
+    gboolean no_owned_found;
   } gt;
 
+#ifdef ESPEAK
+  /* espeak handling */
+  struct {
+    gboolean enabled;
+    int sample_rate;  // or init error
+  } espeak;
+#endif
+
 #ifndef USE_STACKABLE_WINDOW
   GtkWidget *vbox;    
 #endif
