@@ -34,8 +34,8 @@ struct icon_data {
   { NULL, 9 },                            /* ICON_HEADING         */
   { NULL, WPT_SYM_MAX+1 },                /* ICON_WPT             */
   { NULL, 2 },                            /* ICON_TB              */
-  { NULL, 6 },                            /* ICON_MISC            */
-  { NULL, WPT_SYM_MAX+CACHE_TYPE_MAX+10 },/* ICON_POS             */
+  { NULL, 8 },                            /* ICON_MISC            */
+  { NULL, WPT_SYM_MAX+CACHE_TYPE_MAX+11 },/* ICON_POS             */
   { NULL, 3 },                            /* ICON_FILE            */
   { NULL, -1 }
 };
@@ -103,6 +103,16 @@ const char *misc_icon_name[] = {
 #else
   "32x32/gpxview",
 #endif
+#ifndef USE_MAEMO
+  "16x16/speaker", "16x16/speaker_off",
+#else
+#ifndef FREMANTLE
+  "24x24/speaker", "24x24/speaker_off",
+#else
+  "32x32/speaker", "32x32/speaker_off",
+#endif
+#endif
+
   NULL
 };
 
@@ -118,7 +128,7 @@ const char *pos_icon_name[] = {
 
   "pos_wpt", "pos_gps", "pos_geomath", "pos_map", "pos_home",
 
-  "pos_get", "pos_set", "maemo-mapper",
+  "pos_get", "pos_set", "maemo-mapper", "clipboard",
 
   NULL
 };
