@@ -31,6 +31,10 @@
 #include "custom_rating_renderer.h"
 #include "custom_type_renderer.h"
 
+#ifdef ESPEAK
+#include <espeak/speak_lib.h>
+#endif
+
 #ifdef USE_MAEMO
 #include <hildon/hildon-banner.h>
 #if MAEMO_VERSION_MAJOR >= 5
@@ -408,7 +412,6 @@ static void cachelist_update_reset1(GtkAdjustment *adj,
 static gboolean on_cachelist_focus_in(GtkWidget *widget, GdkEventFocus *event,
 				      gpointer data) {
   
-
   /* we don't want a runnign timer yet */
   if(!g_object_get_data(G_OBJECT(data), "handler_id")) {
     printf("focus received: restarting cachelist timer\n");
@@ -419,6 +422,9 @@ static gboolean on_cachelist_focus_in(GtkWidget *widget, GdkEventFocus *event,
 
     g_object_set_data(G_OBJECT(data), "handler_id", (gpointer)
       gtk_timeout_add(CACHELIST_UPDATE_TIMEOUT, cachelist_update, data));  
+
+    /* and redo list immediately */
+    cachelist_redraw(appdata);
   }
 
   return FALSE;
@@ -2053,6 +2059,10 @@ void cleanup(appdata_t *appdata) {
 
   gpx_free_all(appdata->gpx);
 
+#ifdef ESPEAK
+  espeak_Terminate();
+#endif 
+
 #ifdef USE_STACKABLE_WINDOW
   if(appdata->export_menu) submenu_cleanup(appdata->export_menu);
   if(appdata->tools_menu)  submenu_cleanup(appdata->tools_menu);
@@ -2383,6 +2393,32 @@ int main(int argc, char *argv[]) {
 
   curl_global_init(CURL_GLOBAL_ALL);
 
+#ifdef ESPEAK
+#if ESPEAK_API_REVISION == 1
+  appdata.espeak.sample_rate = 
+    espeak_Initialize(AUDIO_OUTPUT_PLAYBACK, 512, NULL);
+#else
+  appdata.espeak.sample_rate =
+    espeak_Initialize(AUDIO_OUTPUT_PLAYBACK, 512, NULL, 0);
+#endif
+  if(appdata.espeak.sample_rate < 0)
+    printf("espeak: init error\n");
+  else
+    printf("espeak: running at %dhz\n", appdata.espeak.sample_rate);
+
+  /* set language */
+  espeak_VOICE voice_spec;
+  voice_spec.name = NULL;
+  voice_spec.languages = _("en");
+  voice_spec.gender = 0;
+  voice_spec.age = 0;
+  voice_spec.variant = 0;
+  if(EE_OK != espeak_SetVoiceByProperties(&voice_spec)) {
+    printf("failed to set voice spec for %s\n", voice_spec.languages);
+    appdata.espeak.sample_rate = -1;
+  }
+#endif
+
 #ifdef USE_MAEMO
   printf("Installing osso context for \"org.harbaum." APP "\"\n");
   appdata.osso_context = osso_initialize("org.harbaum."APP, 
@@ -2470,6 +2506,7 @@ int main(int argc, char *argv[]) {
 
   appdata.gconf_client = gconf_client_get_default();
   gconf_load_state(&appdata);
+
   gps_init(&appdata);
 
   appdata.cur_view = gpxlist_create_view_and_model(&appdata, NULL);
