@@ -290,22 +290,24 @@ static void map_setup(map_context_t *context) {
 
       /* clear all existing cache images */
       osm_gps_map_clear_images (OSM_GPS_MAP(context->widget));
-      memset(context->caches_displayed, 0, 
-	     (cache_num+1) * sizeof(cache_display_t));
 
-      /* draw search results and all other gpx files are semi-transparent */
-      map_draw_gpx(context->appdata, context->caches_displayed, 
-		   context->widget, context->appdata->search_results, 
-		   NULL, FALSE);
+      if(context->caches_displayed) {
+	memset(context->caches_displayed, 0, 
+	       (cache_num+1) * sizeof(cache_display_t));
 
-      gpx_t *gpx = context->appdata->gpx;
-      while(gpx) {
+	/* draw search results and all other gpx files are semi-transparent */
 	map_draw_gpx(context->appdata, context->caches_displayed, 
-		     context->widget, gpx, NULL, TRUE);
+		     context->widget, context->appdata->search_results, 
+		     NULL, FALSE);
 
-	gpx = gpx->next;
+	gpx_t *gpx = context->appdata->gpx;
+	while(gpx) {
+	  map_draw_gpx(context->appdata, context->caches_displayed, 
+		       context->widget, gpx, NULL, TRUE);
+
+	  gpx = gpx->next;
+	}
       }
-
       name = g_strdup(_("Search results"));
       context->state = MAP_SEARCH;
     }
@@ -324,23 +326,24 @@ static void map_setup(map_context_t *context) {
 
       /* clear all existing cache images */
       osm_gps_map_clear_images (OSM_GPS_MAP(context->widget));
-      memset(context->caches_displayed, 0, 
-	     (cache_num+1) * sizeof(cache_display_t));
-
-      /* draw all geocaches and none is semi-transparent */
-      gpx_t *gpx = context->appdata->gpx;
-      while(gpx) {
-	map_draw_gpx(context->appdata, context->caches_displayed, 
-		     context->widget, gpx, NULL, FALSE);
-	gpx = gpx->next;
+      if(context->caches_displayed) {
+	memset(context->caches_displayed, 0, 
+	       (cache_num+1) * sizeof(cache_display_t));
+	
+	/* draw all geocaches and none is semi-transparent */
+	gpx_t *gpx = context->appdata->gpx;
+	while(gpx) {
+	  map_draw_gpx(context->appdata, context->caches_displayed, 
+		       context->widget, gpx, NULL, FALSE);
+	  gpx = gpx->next;
+	}
+	
+	{
+	  int i=0;
+	  while(context->caches_displayed[i].id) i++;
+	  printf("number of caches actually displayed: %d\n", i);
+	}
       }
-
-      {
-	int i=0;
-	while(context->caches_displayed[i].id) i++;
-	printf("number of caches actually displayed: %d\n", i);
-      }
-
       name = g_strdup(_("all"));
       context->state = MAP_ALL;
     }
@@ -359,20 +362,22 @@ static void map_setup(map_context_t *context) {
 
       /* clear all existing cache images */
       osm_gps_map_clear_images (OSM_GPS_MAP(context->widget));
-      memset(context->caches_displayed, 0, 
-	     (cache_num+1) * sizeof(cache_display_t));
-
-      /* draw all geocaches and all other gpx files are semi-transparent */
-      map_draw_gpx(context->appdata, context->caches_displayed, 
-		   context->widget, context->appdata->cur_gpx, NULL, FALSE);
-
-      gpx_t *gpx = context->appdata->gpx;
-      while(gpx) {
-	if(gpx != context->appdata->cur_gpx) 
-	  map_draw_gpx(context->appdata, context->caches_displayed, 
-		       context->widget, gpx, NULL, TRUE);
-
-	gpx = gpx->next;
+      if(context->caches_displayed) {
+	memset(context->caches_displayed, 0, 
+	       (cache_num+1) * sizeof(cache_display_t));
+	
+	/* draw all geocaches and all other gpx files are semi-transparent */
+	map_draw_gpx(context->appdata, context->caches_displayed, 
+		     context->widget, context->appdata->cur_gpx, NULL, FALSE);
+	
+	gpx_t *gpx = context->appdata->gpx;
+	while(gpx) {
+	  if(gpx != context->appdata->cur_gpx) 
+	    map_draw_gpx(context->appdata, context->caches_displayed, 
+			 context->widget, gpx, NULL, TRUE);
+	  
+	  gpx = gpx->next;
+	}
       }
 
       name = g_strdup(context->appdata->cur_gpx->name);
@@ -389,19 +394,21 @@ static void map_setup(map_context_t *context) {
     
     /* clear all existing ccahe images */
     osm_gps_map_clear_images (OSM_GPS_MAP(context->widget));
-    memset(context->caches_displayed, 0, 
-	   (cache_num+1) * sizeof(cache_display_t));
-
-    /* Make sure we really work on the first copy in the list as */
-    /* only this is being used if duplicates exist */
-    cache = cache_search_first(context->appdata->gpx, cache);
-    
-    /* draw all geocaches and all but selected one are semi-transparent */
-    gpx_t *gpx = context->appdata->gpx;
-    while(gpx) {
-      map_draw_gpx(context->appdata, context->caches_displayed, 
-		   context->widget, gpx, cache, FALSE);
-      gpx = gpx->next;
+    if(context->caches_displayed) {
+      memset(context->caches_displayed, 0, 
+	     (cache_num+1) * sizeof(cache_display_t));
+      
+      /* Make sure we really work on the first copy in the list as */
+      /* only this is being used if duplicates exist */
+      cache = cache_search_first(context->appdata->gpx, cache);
+      
+      /* draw all geocaches and all but selected one are semi-transparent */
+      gpx_t *gpx = context->appdata->gpx;
+      while(gpx) {
+	map_draw_gpx(context->appdata, context->caches_displayed, 
+		     context->widget, gpx, cache, FALSE);
+	gpx = gpx->next;
+      }
     }
 
     name = g_strdup(cache->name);
@@ -484,7 +491,8 @@ static cache_t *map_closest(map_context_t *context, pos_t *pos) {
     result = context->appdata->cur_cache;
 
   /* make sure this is the first hit */
-  result = cache_search_first(context->appdata->gpx, result);
+  if(context->caches_displayed) 
+    result = cache_search_first(context->appdata->gpx, result);
 
   return result;
 }
