@@ -1635,7 +1635,6 @@ GtkWidget *preset_coordinate_picker(appdata_t *appdata,
   return button;
 }
 
-#if defined(ENABLE_MAEMO_MAPPER) || defined(ENABLE_OSM_GPS_MAP)
 static pos_t goto_pos_get(GtkWidget *item) {
   pos_t pos;
 
@@ -1648,7 +1647,6 @@ static pos_t goto_pos_get(GtkWidget *item) {
   return  pos;
 }
 
-#if defined(ENABLE_MAEMO_MAPPER) && defined(ENABLE_OSM_GPS_MAP)
 #ifdef ENABLE_MAEMO_MAPPER
 static void cb_mm_set(GtkWidget *item, gpointer data) {
   appdata_t *appdata = (appdata_t*)data;
@@ -1672,6 +1670,21 @@ static void cb_map_set(GtkWidget *item, gpointer data) {
 }
 #endif
 
+static void cb_clipboard_set(GtkWidget *item, gpointer data) {
+  appdata_t *appdata = (appdata_t*)data;
+
+  pos_t pos = goto_pos_get(item);
+  if(!isnan(pos.lat) && !isnan(pos.lon)) {
+    char lat[32], lon[32];
+    pos_lat_str(lat, sizeof(lat), pos.lat); 
+    pos_lon_str(lon, sizeof(lon), pos.lon); 
+
+    char *str = g_strdup_printf("%s %s", lat, lon);
+    gtk_clipboard_set_text(appdata->clipboard, str, -1);
+    g_free(str);
+  }
+}
+
 #ifndef PRESET_PICKER_DIALOG
 static GtkWidget *goto_popup_menu_create(appdata_t *appdata, 
 		    GtkWidget *lat_entry, GtkWidget *lon_entry) {
@@ -1686,6 +1699,9 @@ static GtkWidget *goto_popup_menu_create(appdata_t *appdata,
   menu_add(menu, appdata, icon_get_widget(ICON_POS, 24),
 	   _("Maemo Mapper"), cb_mm_set, 0, lon_entry, lat_entry);
 #endif
+  
+  menu_add(menu, appdata, icon_get_widget(ICON_POS, 25),
+	   _("Clipboard"), cb_clipboard_set, 0, lon_entry, lat_entry);
 
   gtk_widget_show_all(menu);
 
@@ -1731,6 +1747,9 @@ static GtkWidget *goto_picker_create(appdata_t *appdata,
 		    _("Maemo Mapper"), cb_mm_set, 0);
 #endif
 
+  preset_picker_add(store, appdata, icon_get(ICON_POS, 25),
+		    _("Clipboard"), cb_clipboard_set, 0);
+
   gtk_tree_view_set_model(GTK_TREE_VIEW(view), GTK_TREE_MODEL(store));
   g_object_unref(store);
 
@@ -1752,7 +1771,6 @@ static GtkWidget *goto_picker_create(appdata_t *appdata,
 #endif
 }
 #endif
-#endif
 
 static gint on_goto_button_press(GtkWidget *button, 
 				 GdkEventButton *event, gpointer data) {
@@ -1760,21 +1778,6 @@ static gint on_goto_button_press(GtkWidget *button,
   
   if(event->type == GDK_BUTTON_PRESS) {
 
-#if defined(ENABLE_MAEMO_MAPPER) && !defined(ENABLE_OSM_GPS_MAP)
-    /* only maemo mapper is being used */
-    pos_t pos = goto_pos_get(button);
-    if(!isnan(pos.lat) && !isnan(pos.lon)) 
-      dbus_mm_set_position(appdata, &pos);
-#elif !defined(ENABLE_MAEMO_MAPPER) && defined(ENABLE_OSM_GPS_MAP)
-    /* only internal map is being used */
-    pos_t pos = goto_pos_get(button);
-    if(!isnan(pos.lat) && !isnan(pos.lon)) {
-      map(appdata);
-      osm_gps_map_set_center(OSM_GPS_MAP(appdata->map.context->widget), 
-			     pos.lat, pos.lon);
-    }
-#else
-
     gpointer lat_entry = g_object_get_data(G_OBJECT(button), "lat_entry");
     g_assert(lat_entry);
     gpointer lon_entry = g_object_get_data(G_OBJECT(button), "lon_entry");
@@ -1806,8 +1809,6 @@ static gint on_goto_button_press(GtkWidget *button,
     gtk_widget_show_all(dialog);
     gtk_dialog_run(GTK_DIALOG(dialog));
     gtk_widget_destroy(dialog);
-#endif
-
 #endif
     
     return TRUE;
@@ -1846,13 +1847,6 @@ GtkWidget *goto_coordinate(appdata_t *appdata,
   
   return button;
 }
-#else
-/* no map installed */
-GtkWidget *goto_coordinate(appdata_t *appdata, 
-		     GtkWidget *lat_entry, GtkWidget *lon_entry) {
-  return gtk_label_new("");
-}
-#endif
 
 GtkWidget *entry_new(void) {
 #if !defined(USE_MAEMO) || (MAEMO_VERSION_MAJOR < 5)
@@ -2161,6 +2155,7 @@ GtkWidget *export_file(char *sel_title, char **filename) {
 #endif
 }
 
+#ifdef FREMANTLE
 static int number_editor_get(GtkWidget *widget) {
   GtkWidget *entry = g_object_get_data(G_OBJECT(widget), "entry");
   g_assert(entry);
@@ -2205,6 +2200,7 @@ static void on_number_changed(GtkWidget *widget, gpointer data) {
   number_editor_set(GTK_WIDGET(data), 
     number_editor_get(GTK_WIDGET(data)));
 }
+#endif
 
 GtkWidget *number_editor_new(int current, int min, int max) {
 #ifndef USE_MAEMO
