@@ -19,6 +19,7 @@
 
 #include <stdio.h>
 #include <string.h>
+#include <errno.h>
 
 #include <glib/gunicode.h>
 
@@ -877,14 +878,14 @@ void notes_log_export(appdata_t *appdata) {
     time_t now = time(NULL);
     struct tm *tm_now = localtime(&now);
     char now_str[32];
-    strftime(now_str, sizeof(now_str)-1, "%F_%H:%M", tm_now);
+    strftime(now_str, sizeof(now_str)-1, "%F_%H-%M", tm_now);
     char *fname = g_strdup_printf(appdata->fieldnotes_path, now_str);
+
     printf("--- about to export logs to %s ---\n", fname);
     FILE *file = fopen(fname, "w");
     g_free(fname);
 
     if(file) {
-
       llog = log;
       while(llog) {
 	printf("Exporting %s\n", llog->cache->id);
@@ -974,7 +975,9 @@ void notes_log_export(appdata_t *appdata) {
       }
     
       fclose(file);
-    }
+    } else 
+      errorf(_("Can't open file:\n\n%s"), strerror(errno));
+
   } else {
     /* restore old path, in case it has been altered but not been used */
     free(appdata->fieldnotes_path);
